==========
Change Log
==========

This document records all notable changes to `fastcrc <https://github.com/overcat/fastcrc/>`_.

0.2.0 (June 19, 2022)
---------------------
* Add initial value optional parameter to all CRC functions. (`#1 <https://github.com/overcat/fastcrc/pull/1>`_)

0.1.1 (May 23, 2021)
---------------------
* Correct the project information.

0.1.0 (May 23, 2021)
---------------------
* First release.
